import javax.bluetooth.BluetoothStateException;
import javax.bluetooth.DiscoveryAgent;
import javax.bluetooth.RemoteDevice;



/**
 * @author Gregor Broll, Alex De Luca
 * 
 * This class implements the actual search for bluetooth devices
 */
public class BTDeviceSearch implements Runnable
{
	private BTGPSMidlet midlet;
	private DiscoveryAgent agent;
	
	
	/**
	 * Constructor
	 * 
	 * @param midlet
	 * @param agent
	 */
	public BTDeviceSearch(BTGPSMidlet midlet, DiscoveryAgent agent)
	{
		this.midlet = midlet;
		this.agent = agent;
	}
	

	/**
	 * Searches for cached, preknown and all other Bluetooth devices
	 */
	public void run() 
	{
		//search for cached devices
        RemoteDevice[] cachedDevices = agent.retrieveDevices(DiscoveryAgent.CACHED);
        if (cachedDevices != null) 
        {
            for (int i=0; i<cachedDevices.length; i++) 
            {
            	midlet.deviceDiscovered(cachedDevices[i], null);
            }
        }

        //search for preknown devices
        RemoteDevice[] preknownDevices = agent.retrieveDevices(DiscoveryAgent.PREKNOWN);
        if (preknownDevices != null) 
        {
            for (int i=0; i<preknownDevices.length; i++) 
            {
            	midlet.deviceDiscovered(preknownDevices[i], null);
            }
        }

        try 
        {
        	//search for all bluetooth devices
            agent.startInquiry(DiscoveryAgent.GIAC, midlet);
        } 
        catch(BluetoothStateException bse) 
        {
            // Display error message
            System.out.println("Inquiry Failed");
            return;
        }
	}
	
	
	/**
	 * Used to cancel the inquiry
	 */
	public void cancelInquiry(BTGPSMidlet midlet)
	{
		agent.cancelInquiry(midlet);
	}
}
